## Copyright (C) 2004  Dragan Tubic
## 
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
## 
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details. 
## 
## You should have received a copy of the GNU General Public License
## along with this file.  If not, write to the Free Software Foundation,
## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} vtk_close(@var{n})
## Closes the specified vtk figure window.  All structures referencing
## the figure window (perhaps 'ans') must be cleared from userspace
## in order for the window to close.
## @end deftypefn
## @seealso{vtk_clear}

## Author: Dragan Tubic

function f = vtk_close( fig_no )
	vtk_figure( -abs(fig_no) );
endfunction
